/* Dispatcher.c */

#include <Types.h>
#include <Quickdraw.h>
#include <Controls.h>
#include <Dialogs.h>
#include <Events.h>
#include <Lists.h>
#include <Menus.h>
#include <TextEdit.h>

#include "EverythingApp.h"
#include "EverythingDoc.h"
#include "EverythingEngine.h"
#include "Buttons.h"
#include "Checkboxes.h"
#include "Radios.h"
#include "EditText.h"
#include "Stuff.h"
#include "Bars.h"
#include "AboutDialog.h"
#include "ModalButtons.h"
#include "ModalCheckboxes.h"
#include "ModalRadios.h"
#include "ModalText.h"
#include "ModalStuff.h"
#include "ModalBars.h"
#include "ModelessButtons.h"
#include "ModelessCheckboxes.h"
#include "ModelessRadios.h"
#include "ModelessText.h"
#include "ModelessStuff.h"
#include "ModelessBars.h"

#include "Globals.h"
#include "Dispatcher.h"

/*----------*/
void DoIdle (void)
{
}

//----------
// windows

//----------
void	Close (
	AMWindow*		window)
{
	switch (GetClassID (window)) {
	case classButtons:
			Buttons_Close ((Buttons*) window);
		break;
	case classCheckboxes:
			Checkboxes_Close ((Checkboxes*) window);
		break;
	case classRadios:
			Radios_Close ((Radios*) window);
		break;
	case classEditText:
			EditText_Close ((EditText*) window);
		break;
	case classStuff:
			Stuff_Close ((Stuff*) window);
		break;
	case classBars:
			Bars_Close ((Bars*) window);
		break;
	} // switch
}

//----------
void	DoTrack (
	AMWindow*		window,
	ControlHandle	whichControl,
	short	 		whichPart,
	Point			where)
{
	switch (GetClassID (window)) {
	case classButtons:
			Buttons_Track ((Buttons*) window, whichControl, whichPart, where);
		break;
	case classCheckboxes:
			Checkboxes_Track ((Checkboxes*) window, whichControl, whichPart, where);
		break;
	case classRadios:
			Radios_Track ((Radios*) window, whichControl, whichPart, where);
		break;
	case classEditText:
			EditText_Track ((EditText*) window, whichControl, whichPart, where);
		break;
	case classStuff:
			Stuff_Track ((Stuff*) window, whichControl, whichPart, where);
		break;
	case classBars:
			Bars_Track ((Bars*) window, whichControl, whichPart, where);
		break;
	} // switch
}

//----------
void	MouseIn (
	AMWindow*		window,
	Point			where,
	short			modifiers)
{
	switch (GetClassID (window)) {
	case classButtons:
			Buttons_MouseIn ((Buttons*) window, where, modifiers);
		break;
	case classCheckboxes:
			Checkboxes_MouseIn ((Checkboxes*) window, where, modifiers);
		break;
	case classRadios:
			Radios_MouseIn ((Radios*) window, where, modifiers);
		break;
	case classEditText:
			EditText_MouseIn ((EditText*) window, where, modifiers);
		break;
	case classStuff:
			Stuff_MouseIn ((Stuff*) window, where, modifiers);
		break;
	case classBars:
			Bars_MouseIn ((Bars*) window, where, modifiers);
		break;
	} // switch
}

//----------
void	TypeIn (
	AMWindow*		window,
	char			ch)
{
	switch (GetClassID (window)) {
	case classButtons:
			Buttons_TypeIn ((Buttons*) window, ch);
		break;
	case classCheckboxes:
			Checkboxes_TypeIn ((Checkboxes*) window, ch);
		break;
	case classRadios:
			Radios_TypeIn ((Radios*) window, ch);
		break;
	case classEditText:
			EditText_TypeIn ((EditText*) window, ch);
		break;
	case classStuff:
			Stuff_TypeIn ((Stuff*) window, ch);
		break;
	case classBars:
			Bars_TypeIn ((Bars*) window, ch);
		break;
	} // switch
}

//----------
void	Resize (
	AMWindow*		window)
{
	switch (GetClassID (window)) {
	case classButtons:
			Buttons_Resize ((Buttons*) window);
		break;
	case classCheckboxes:
			Checkboxes_Resize ((Checkboxes*) window);
		break;
	case classRadios:
			Radios_Resize ((Radios*) window);
		break;
	case classEditText:
			EditText_Resize ((EditText*) window);
		break;
	case classStuff:
			Stuff_Resize ((Stuff*) window);
		break;
	case classBars:
			Bars_Resize ((Bars*) window);
		break;
	} // switch
}

//----------
void	Scroll (
	AMWindow*		window,
	short			newValue,
	short			oldValue)
{
	switch (GetClassID (window)) {
	case classButtons:
			Buttons_Scroll ((Buttons*) window, newValue, oldValue);
		break;
	case classCheckboxes:
			Checkboxes_Scroll ((Checkboxes*) window, newValue, oldValue);
		break;
	case classRadios:
			Radios_Scroll ((Radios*) window, newValue, oldValue);
		break;
	case classEditText:
			EditText_Scroll ((EditText*) window, newValue, oldValue);
		break;
	case classStuff:
			Stuff_Scroll ((Stuff*) window, newValue, oldValue);
		break;
	case classBars:
			Bars_Scroll ((Bars*) window, newValue, oldValue);
		break;
	} // switch
}

//----------
Boolean	DoCommand (
	AMWindow*		window,
	long			inCommand)
{
	switch (GetClassID (window)) {
	case classButtons:
			return Buttons_DoCommand ((Buttons*) window, inCommand);
		break;
	case classCheckboxes:
			return Checkboxes_DoCommand ((Checkboxes*) window, inCommand);
		break;
	case classRadios:
			return Radios_DoCommand ((Radios*) window, inCommand);
		break;
	case classEditText:
			return EditText_DoCommand ((EditText*) window, inCommand);
		break;
	case classStuff:
			return Stuff_DoCommand ((Stuff*) window, inCommand);
		break;
	case classBars:
			return Bars_DoCommand ((Bars*) window, inCommand);
		break;
	} // switch
	return false;
}

//----------
void	ExitCurField (
	AMWindow*		window)
{
	switch (GetClassID (window)) {
	case classButtons:
			Buttons_ExitCurField ((Buttons*) window);
		break;
	case classCheckboxes:
			Checkboxes_ExitCurField ((Checkboxes*) window);
		break;
	case classRadios:
			Radios_ExitCurField ((Radios*) window);
		break;
	case classEditText:
			EditText_ExitCurField ((EditText*) window);
		break;
	case classStuff:
			Stuff_ExitCurField ((Stuff*) window);
		break;
	case classBars:
			Bars_ExitCurField ((Bars*) window);
		break;
	} // switch
}

//----------
void	DataChanged (
	AMResponder*	responder,
	long			inDataID)
{
	switch (GetClassID (responder)) {
	case classButtons:
			Buttons_DataChanged ((Buttons*) responder, inDataID);
		break;
	case classCheckboxes:
			Checkboxes_DataChanged ((Checkboxes*) responder, inDataID);
		break;
	case classRadios:
			Radios_DataChanged ((Radios*) responder, inDataID);
		break;
	case classEditText:
			EditText_DataChanged ((EditText*) responder, inDataID);
		break;
	case classStuff:
			Stuff_DataChanged ((Stuff*) responder, inDataID);
		break;
	case classBars:
			Bars_DataChanged ((Bars*) responder, inDataID);
		break;
	case classAboutDialog:
			AboutDialog_DataChanged ((AboutDialog*) responder, inDataID);
		break;
	case classModalButtons:
			ModalButtons_DataChanged ((ModalButtons*) responder, inDataID);
		break;
	case classModalCheckboxes:
			ModalCheckboxes_DataChanged ((ModalCheckboxes*) responder, inDataID);
		break;
	case classModalRadios:
			ModalRadios_DataChanged ((ModalRadios*) responder, inDataID);
		break;
	case classModalText:
			ModalText_DataChanged ((ModalText*) responder, inDataID);
		break;
	case classModalStuff:
			ModalStuff_DataChanged ((ModalStuff*) responder, inDataID);
		break;
	case classModalBars:
			ModalBars_DataChanged ((ModalBars*) responder, inDataID);
		break;
	case classModelessButtons:
			ModelessButtons_DataChanged ((ModelessButtons*) responder, inDataID);
		break;
	case classModelessCheckboxes:
			ModelessCheckboxes_DataChanged ((ModelessCheckboxes*) responder, inDataID);
		break;
	case classModelessRadios:
			ModelessRadios_DataChanged ((ModelessRadios*) responder, inDataID);
		break;
	case classModelessText:
			ModelessText_DataChanged ((ModelessText*) responder, inDataID);
		break;
	case classModelessStuff:
			ModelessStuff_DataChanged ((ModelessStuff*) responder, inDataID);
		break;
	case classModelessBars:
			ModelessBars_DataChanged ((ModelessBars*) responder, inDataID);
		break;
	} // switch
}

//----------
// dialogs

//----------
void	FinishMake (
	AMDialog*		dialog)
{
	switch (GetClassID (dialog)) {
	case classAboutDialog:
			AboutDialog_FinishMake ((AboutDialog*) dialog);
		break;
	case classModalButtons:
			ModalButtons_FinishMake ((ModalButtons*) dialog);
		break;
	case classModalCheckboxes:
			ModalCheckboxes_FinishMake ((ModalCheckboxes*) dialog);
		break;
	case classModalRadios:
			ModalRadios_FinishMake ((ModalRadios*) dialog);
		break;
	case classModalText:
			ModalText_FinishMake ((ModalText*) dialog);
		break;
	case classModalStuff:
			ModalStuff_FinishMake ((ModalStuff*) dialog);
		break;
	case classModalBars:
			ModalBars_FinishMake ((ModalBars*) dialog);
		break;
	case classModelessButtons:
			ModelessButtons_FinishMake ((ModelessButtons*) dialog);
		break;
	case classModelessCheckboxes:
			ModelessCheckboxes_FinishMake ((ModelessCheckboxes*) dialog);
		break;
	case classModelessRadios:
			ModelessRadios_FinishMake ((ModelessRadios*) dialog);
		break;
	case classModelessText:
			ModelessText_FinishMake ((ModelessText*) dialog);
		break;
	case classModelessStuff:
			ModelessStuff_FinishMake ((ModelessStuff*) dialog);
		break;
	case classModelessBars:
			ModelessBars_FinishMake ((ModelessBars*) dialog);
		break;
	} // switch
}

//----------
void	ConnectToData (
	AMDialog*		dialog,
	AMSignaler*		inData)
{
	switch (GetClassID (dialog)) {
	case classAboutDialog:
			AboutDialog_ConnectToData ((AboutDialog*) dialog, inData);
		break;
	case classModalButtons:
			ModalButtons_ConnectToData ((ModalButtons*) dialog, inData);
		break;
	case classModalCheckboxes:
			ModalCheckboxes_ConnectToData ((ModalCheckboxes*) dialog, inData);
		break;
	case classModalRadios:
			ModalRadios_ConnectToData ((ModalRadios*) dialog, inData);
		break;
	case classModalText:
			ModalText_ConnectToData ((ModalText*) dialog, inData);
		break;
	case classModalStuff:
			ModalStuff_ConnectToData ((ModalStuff*) dialog, inData);
		break;
	case classModalBars:
			ModalBars_ConnectToData ((ModalBars*) dialog, inData);
		break;
	case classModelessButtons:
			ModelessButtons_ConnectToData ((ModelessButtons*) dialog, inData);
		break;
	case classModelessCheckboxes:
			ModelessCheckboxes_ConnectToData ((ModelessCheckboxes*) dialog, inData);
		break;
	case classModelessRadios:
			ModelessRadios_ConnectToData ((ModelessRadios*) dialog, inData);
		break;
	case classModelessText:
			ModelessText_ConnectToData ((ModelessText*) dialog, inData);
		break;
	case classModelessStuff:
			ModelessStuff_ConnectToData ((ModelessStuff*) dialog, inData);
		break;
	case classModelessBars:
			ModelessBars_ConnectToData ((ModelessBars*) dialog, inData);
		break;
	} // switch
}

//----------
void	DoItem (
	AMDialog*		dialog,
	SInt16			inItemHit)
{
	switch (GetClassID (dialog)) {
	case classAboutDialog:
			AboutDialog_DoItem ((AboutDialog*) dialog, inItemHit);
		break;
	case classModalButtons:
			ModalButtons_DoItem ((ModalButtons*) dialog, inItemHit);
		break;
	case classModalCheckboxes:
			ModalCheckboxes_DoItem ((ModalCheckboxes*) dialog, inItemHit);
		break;
	case classModalRadios:
			ModalRadios_DoItem ((ModalRadios*) dialog, inItemHit);
		break;
	case classModalText:
			ModalText_DoItem ((ModalText*) dialog, inItemHit);
		break;
	case classModalStuff:
			ModalStuff_DoItem ((ModalStuff*) dialog, inItemHit);
		break;
	case classModalBars:
			ModalBars_DoItem ((ModalBars*) dialog, inItemHit);
		break;
	case classModelessButtons:
			ModelessButtons_DoItem ((ModelessButtons*) dialog, inItemHit);
		break;
	case classModelessCheckboxes:
			ModelessCheckboxes_DoItem ((ModelessCheckboxes*) dialog, inItemHit);
		break;
	case classModelessRadios:
			ModelessRadios_DoItem ((ModelessRadios*) dialog, inItemHit);
		break;
	case classModelessText:
			ModelessText_DoItem ((ModelessText*) dialog, inItemHit);
		break;
	case classModelessStuff:
			ModelessStuff_DoItem ((ModelessStuff*) dialog, inItemHit);
		break;
	case classModelessBars:
			ModelessBars_DoItem ((ModelessBars*) dialog, inItemHit);
		break;
	} // switch
}

//----------
Boolean		Filter (
	AMDialog*			dialog,
	EventRecord			*ioEvent,
	DialogItemIndex		*outItemHit)
{
	switch (GetClassID (dialog)) {
	case classAboutDialog:
			return AboutDialog_Filter ((AboutDialog*) dialog, ioEvent, outItemHit);
		break;
	case classModalButtons:
			return ModalButtons_Filter ((ModalButtons*) dialog, ioEvent, outItemHit);
		break;
	case classModalCheckboxes:
			return ModalCheckboxes_Filter ((ModalCheckboxes*) dialog, ioEvent, outItemHit);
		break;
	case classModalRadios:
			return ModalRadios_Filter ((ModalRadios*) dialog, ioEvent, outItemHit);
		break;
	case classModalText:
			return ModalText_Filter ((ModalText*) dialog, ioEvent, outItemHit);
		break;
	case classModalStuff:
			return ModalStuff_Filter ((ModalStuff*) dialog, ioEvent, outItemHit);
		break;
	case classModalBars:
			return ModalBars_Filter ((ModalBars*) dialog, ioEvent, outItemHit);
		break;
	case classModelessButtons:
			return ModelessButtons_Filter ((ModelessButtons*) dialog, ioEvent, outItemHit);
		break;
	case classModelessCheckboxes:
			return ModelessCheckboxes_Filter ((ModelessCheckboxes*) dialog, ioEvent, outItemHit);
		break;
	case classModelessRadios:
			return ModelessRadios_Filter ((ModelessRadios*) dialog, ioEvent, outItemHit);
		break;
	case classModelessText:
			return ModelessText_Filter ((ModelessText*) dialog, ioEvent, outItemHit);
		break;
	case classModelessStuff:
			return ModelessStuff_Filter ((ModelessStuff*) dialog, ioEvent, outItemHit);
		break;
	case classModelessBars:
			return ModelessBars_Filter ((ModelessBars*) dialog, ioEvent, outItemHit);
		break;
	} // switch
	return false;	// not filtered => Dialog Manager takes it
}

//----------
// modeless dialogs

/*----------*/
void	InitModelessDialogs (void)
{
	ModelessButtons_Create ();
	ModelessCheckboxes_Create ();
	ModelessRadios_Create ();
	ModelessText_Create ();
	ModelessStuff_Create ();
	ModelessBars_Create ();

}

/*----------*/
void	CloseModelessDialog (
	DialogPtr		whichDialog)
{
	if (whichDialog == ModelessButtonsDialog) {
		ModelessButtons_Close ();
	}
	if (whichDialog == ModelessCheckboxesDialog) {
		ModelessCheckboxes_Close ();
	}
	if (whichDialog == ModelessRadiosDialog) {
		ModelessRadios_Close ();
	}
	if (whichDialog == ModelessTextDialog) {
		ModelessText_Close ();
	}
	if (whichDialog == ModelessStuffDialog) {
		ModelessStuff_Close ();
	}
	if (whichDialog == ModelessBarsDialog) {
		ModelessBars_Close ();
	}

}
