// EverythingApp.c -- application-level functions

#include <Types.h>
#include <Quickdraw.h>
#include <Controls.h>
#include <Events.h>
#include <Lists.h>
#include <Menus.h>
#include <TextEdit.h>
#include <stdlib.h>

#include "ResourceDefs.h"
#include "Dispatcher.h"

#include "ModelessButtons.h"
#include "ModelessCheckboxes.h"
#include "ModelessRadios.h"
#include "ModelessText.h"
#include "ModelessStuff.h"
#include "ModelessBars.h"
#include "AboutDialog.h"
#include "EverythingEngine.h"
#include "EverythingDoc.h"
#include "AMWindow.h"
#include "EverythingApp.h"

static	void	DoModelessButtons	(AMApp*		self);
static	void	DoModelessCheckboxes	(AMApp*		self);
static	void	DoModelessRadios	(AMApp*		self);
static	void	DoModelessText	(AMApp*		self);
static	void	DoModelessStuff	(AMApp*		self);
static	void	DoModelessMoreStuff	(AMApp*		self);
static	void	DoInvokeAbout	(AMApp*		self);

//----------
EverythingApp*		NewEverythingApp ()
{
	EverythingApp*		app;

	app = (EverythingApp*)malloc (sizeof (EverythingApp));
	EverythingApp_Init (app);
	SetClassID (app, classEverythingApp);

	return app;
}

//----------
void	DeleteApp (
	AMApp*		app)
{
	EverythingApp_Free ((EverythingApp*)app);
	free (app);
}

/*----------*/
void	EverythingApp_Init (
	EverythingApp*		self)
{
	AMApp_Init ((AMApp*) self);

	self->super.mNumOpenTypes = 1;
	self->super.mOpenTypeList [0] = kFileType;
}

/*----------*/
void	EverythingApp_Free (
	EverythingApp*		self)
{
	AMApp_Free ((AMApp*) self);
}

/*----------*/
AMDoc*		MakeDoc (
	AMApp*		self)
{
	EverythingDoc*		doc = NewEverythingDoc ();

	if (doc != nil) {
		//? add to list of docs
	}

	return (AMDoc*) doc;
}

/*----------*/
void	OpenApp (
	AMApp*		self)
{
	DoNew (self);
}

//----------
void	DoModelessButtons (
AMApp*		self)
{
	ModelessButtons_Show ();
}

//----------
void	DoModelessCheckboxes (
AMApp*		self)
{
	ModelessCheckboxes_Show ();
}

//----------
void	DoModelessRadios (
AMApp*		self)
{
	ModelessRadios_Show ();
}

//----------
void	DoModelessText (
AMApp*		self)
{
	ModelessText_Show ();
}

//----------
void	DoModelessStuff (
AMApp*		self)
{
	ModelessStuff_Show ();
}

//----------
void	DoModelessMoreStuff (
AMApp*		self)
{
	ModelessBars_Show ();
}

//----------
void	DoInvokeAbout (
AMApp*		self)
{
	if (GetAboutDialog ()) {
		/* do something */
	}
}

//----------
Boolean		DoAppCommand (
	AMApp*		self,
	long		inCommand)
{
	Boolean		result = true;

	switch (inCommand) {
		case cmdNew:
				DoNew (self);
			break;
		case cmdOpen:
				DoOpen (self);
			break;
		case cmdClose:
				DoClose (self);
			break;
		case cmdQuit:
				DoQuit (self);
			break;
		case cmdModelessButtons:
				DoModelessButtons (self);
			break;
		case cmdModelessCheckboxes:
				DoModelessCheckboxes (self);
			break;
		case cmdModelessRadios:
				DoModelessRadios (self);
			break;
		case cmdModelessText:
				DoModelessText (self);
			break;
		case cmdModelessStuff:
				DoModelessStuff (self);
			break;
		case cmdModelessMoreStuff:
				DoModelessMoreStuff (self);
			break;
		case cmdInvokeAbout:
				DoInvokeAbout (self);
			break;

		default:
				result = false;
	} // case

	return result;
}
