/* ModalBars.c -- Modal dialog */

#include <Types.h>
#include <Quickdraw.h>
#include <Controls.h>
#include <Dialogs.h>
#include <Events.h>
#include <Lists.h>
#include <Menus.h>
#include <TextEdit.h>
#include <Appearance.h>
#include <stdlib.h>

#include "ResourceDefs.h"
#include "Miscellany.h"
#include "ControlUtils.h"

#include "Dispatcher.h"
#include "ModalBars.h"

#define kOKButton		1
#define kBarsPanel		2
#define kScrollBarsLayer		3
#define kStandardScroll		4
#define kGraphicScroll		5
#define kSliderScroll		6
#define kTickMarksScroll		7
#define kNonDirectionalScroll		8
#define kLittleArrowsScroll		9
#define kSpinnerScroll		10
#define kVolumeControlScroll		11
#define kJimSSliderScroll		12
#define kProgressBarsLayer		13
#define kStandard2Bar			14
#define kIndeterminateBar			15
#define kChasingArrowsBar			16
#define kRectangleBar			17
#define kRoundRectBar			18
#define kBarberPoleBar			19
#define kRoundBarberBar			20


/*----------*/
Boolean		GetModalBars (
	DModalBarsData*		ioData)
{
	Boolean			result = false;
	ModalBars*		dialog = NewModalBars ();

	result = AMDialog_RunModal ((AMDialog*)dialog, DLOG_ModalBars, (AMSignaler*)ioData);

	DeleteModalBars (dialog);

	return result;
}

//----------
ModalBars*		NewModalBars ()
{
	ModalBars*		dialog;

	dialog = (ModalBars*)malloc (sizeof (ModalBars));
	ModalBars_Init (dialog);
	SetClassID (dialog, classModalBars);

	return dialog;
}

//----------
void	DeleteModalBars (
	ModalBars*		dialog)
{
	ModalBars_Free (dialog);
	free (dialog);
}

//----------
void	ModalBars_Init (
	ModalBars*		self)
{
	AMDialog_Init ((AMDialog*)self);
}

//----------
void	ModalBars_Free (
	ModalBars*		self)
{
	AMDialog_Free ((AMDialog*)self);
}

//----------
void	ModalBars_FinishMake (
	ModalBars*		self)
{
	self->mOKHandle = AMDialog_GetControlItem ((AMDialog*)self, kOKButton);
	SetDefaultState (self->mOKHandle, true);
	SetDialogDefaultItem (((AMDialog*)self)->mDialog, kOKButton);
	self->mBarsHandle = AMDialog_GetControlItem ((AMDialog*)self, kBarsPanel);
	self->mStandardHandle = AMDialog_GetControlItem ((AMDialog*)self, kStandardScroll);
	self->mGraphicHandle = AMDialog_GetControlItem ((AMDialog*)self, kGraphicScroll);
	self->mSliderHandle = AMDialog_GetControlItem ((AMDialog*)self, kSliderScroll);
	self->mTickMarksHandle = AMDialog_GetControlItem ((AMDialog*)self, kTickMarksScroll);
	self->mNonDirectionalHandle = AMDialog_GetControlItem ((AMDialog*)self, kNonDirectionalScroll);
	self->mLittleArrowsHandle = AMDialog_GetControlItem ((AMDialog*)self, kLittleArrowsScroll);
	self->mSpinnerHandle = AMDialog_GetControlItem ((AMDialog*)self, kSpinnerScroll);
	self->mVolumeControlHandle = AMDialog_GetControlItem ((AMDialog*)self, kVolumeControlScroll);
	self->mJimSSliderHandle = AMDialog_GetControlItem ((AMDialog*)self, kJimSSliderScroll);
	self->mStandard2Handle = AMDialog_GetControlItem ((AMDialog*)self, kStandard2Bar);
	self->mIndeterminateHandle = AMDialog_GetControlItem ((AMDialog*)self, kIndeterminateBar);
	self->mChasingArrowsHandle = AMDialog_GetControlItem ((AMDialog*)self, kChasingArrowsBar);
	self->mRectangleHandle = AMDialog_GetControlItem ((AMDialog*)self, kRectangleBar);
	self->mRoundRectHandle = AMDialog_GetControlItem ((AMDialog*)self, kRoundRectBar);
	self->mBarberPoleHandle = AMDialog_GetControlItem ((AMDialog*)self, kBarberPoleBar);
	self->mRoundBarberHandle = AMDialog_GetControlItem ((AMDialog*)self, kRoundBarberBar);
}

//----------
void	ModalBars_ConnectToData (
	ModalBars*		self,
	AMSignaler*		inData)
{
	AMDialog_ConnectToData ((AMDialog*)self, inData);
	self->mData = (DModalBarsData*) inData;

	SetControlValue (self->mBarsHandle, GetBars2 (self->mData));
	SetLayerGroupValue (self->mBarsHandle, GetControlValue (self->mBarsHandle));
	SetControlValue (self->mStandardHandle, GetStandard5 (self->mData));
	SetControlValue (self->mGraphicHandle, GetGraphic4 (self->mData));
	SetControlValue (self->mSliderHandle, GetSlider2 (self->mData));
	SetControlValue (self->mTickMarksHandle, GetTickMarks2 (self->mData));
	SetControlValue (self->mNonDirectionalHandle, GetNonDirectional2 (self->mData));
	SetControlValue (self->mLittleArrowsHandle, GetLittleArrows2 (self->mData));
	SetControlValue (self->mSpinnerHandle, GetSpinner2 (self->mData));
	SetControlValue (self->mVolumeControlHandle, GetVolumeControl2 (self->mData));
	SetControlValue (self->mJimSSliderHandle, GetJimSSlider2 (self->mData));
	SetControlValue (self->mStandard2Handle, GetStandard6 (self->mData));
	SetControlValue (self->mIndeterminateHandle, GetIndeterminate2 (self->mData));
	SetControlValue (self->mChasingArrowsHandle, GetChasingArrows2 (self->mData));
	SetControlValue (self->mRectangleHandle, GetRectangle2 (self->mData));
	SetControlValue (self->mRoundRectHandle, GetRoundRect2 (self->mData));
	SetControlValue (self->mBarberPoleHandle, GetBarberPole2 (self->mData));
	SetControlValue (self->mRoundBarberHandle, GetRoundBarber2 (self->mData));
}

//----------
void	ModalBars_DoItem (
	ModalBars*		self,
	SInt16		inItemHit)
{
	switch (inItemHit) {
	case kOKButton:
			AMDialog_SetResult ((AMDialog*)self, true);
		break;
	case kBarsPanel:
			SetBars2 (self->mData, GetControlValue (self->mBarsHandle));
			SetLayerGroupValue (self->mBarsHandle, GetControlValue (self->mBarsHandle));
		break;
	case kStandardScroll:
			SetStandard5 (self->mData, GetControlValue (self->mStandardHandle));
		break;
	case kGraphicScroll:
			SetGraphic4 (self->mData, GetControlValue (self->mGraphicHandle));
		break;
	case kSliderScroll:
			SetSlider2 (self->mData, GetControlValue (self->mSliderHandle));
		break;
	case kTickMarksScroll:
			SetTickMarks2 (self->mData, GetControlValue (self->mTickMarksHandle));
		break;
	case kNonDirectionalScroll:
			SetNonDirectional2 (self->mData, GetControlValue (self->mNonDirectionalHandle));
		break;
	case kLittleArrowsScroll:
			SetLittleArrows2 (self->mData, GetControlValue (self->mLittleArrowsHandle));
		break;
	case kSpinnerScroll:
			SetSpinner2 (self->mData, GetControlValue (self->mSpinnerHandle));
		break;
	case kVolumeControlScroll:
			SetVolumeControl2 (self->mData, GetControlValue (self->mVolumeControlHandle));
		break;
	case kJimSSliderScroll:
			SetJimSSlider2 (self->mData, GetControlValue (self->mJimSSliderHandle));
		break;

	} // switch
}

//----------
void	ModalBars_DataChanged (
	ModalBars*		self,
	long		inDataID)
{
	if (inDataID == idBars2) {
		SetControlValue (self->mBarsHandle, GetBars2 (self->mData));
		SetLayerGroupValue (self->mBarsHandle, GetBars2 (self->mData));
	}
	if (inDataID == idStandard5) {
		SetControlValue (self->mStandardHandle, GetStandard5 (self->mData));
	}
	if (inDataID == idGraphic4) {
		SetControlValue (self->mGraphicHandle, GetGraphic4 (self->mData));
	}
	if (inDataID == idSlider2) {
		SetControlValue (self->mSliderHandle, GetSlider2 (self->mData));
	}
	if (inDataID == idTickMarks2) {
		SetControlValue (self->mTickMarksHandle, GetTickMarks2 (self->mData));
	}
	if (inDataID == idNonDirectional2) {
		SetControlValue (self->mNonDirectionalHandle, GetNonDirectional2 (self->mData));
	}
	if (inDataID == idLittleArrows2) {
		SetControlValue (self->mLittleArrowsHandle, GetLittleArrows2 (self->mData));
	}
	if (inDataID == idSpinner2) {
		SetControlValue (self->mSpinnerHandle, GetSpinner2 (self->mData));
	}
	if (inDataID == idVolumeControl2) {
		SetControlValue (self->mVolumeControlHandle, GetVolumeControl2 (self->mData));
	}
	if (inDataID == idJimSSlider2) {
		SetControlValue (self->mJimSSliderHandle, GetJimSSlider2 (self->mData));
	}
	if (inDataID == idStandard6) {
		SetControlValue (self->mStandard2Handle, GetStandard6 (self->mData));
	}
	if (inDataID == idIndeterminate2) {
		SetControlValue (self->mIndeterminateHandle, GetIndeterminate2 (self->mData));
	}
	if (inDataID == idChasingArrows2) {
		SetControlValue (self->mChasingArrowsHandle, GetChasingArrows2 (self->mData));
	}
	if (inDataID == idRectangle2) {
		SetControlValue (self->mRectangleHandle, GetRectangle2 (self->mData));
	}
	if (inDataID == idRoundRect2) {
		SetControlValue (self->mRoundRectHandle, GetRoundRect2 (self->mData));
	}
	if (inDataID == idBarberPole2) {
		SetControlValue (self->mBarberPoleHandle, GetBarberPole2 (self->mData));
	}
	if (inDataID == idRoundBarber2) {
		SetControlValue (self->mRoundBarberHandle, GetRoundBarber2 (self->mData));
	}
}

//----------
Boolean		ModalBars_Filter (
	ModalBars*			self,
	EventRecord			*ioEvent,
	DialogItemIndex		*outItemHit)
{
	return AMDialog_Filter ((AMDialog*)self, ioEvent, outItemHit);
}
