/* ModalCheckboxes.c -- Modal dialog */

#include <Types.h>
#include <Quickdraw.h>
#include <Controls.h>
#include <Dialogs.h>
#include <Events.h>
#include <Lists.h>
#include <Menus.h>
#include <TextEdit.h>
#include <Appearance.h>
#include <stdlib.h>

#include "ResourceDefs.h"
#include "Miscellany.h"
#include "ControlUtils.h"

#include "Dispatcher.h"
#include "ModalCheckboxes.h"

#define kOKButton		1
#define kStandardCheck		2
#define kXxCheck		3
#define kCapTriangleLabel		4
#define kGraphicBox		5
#define kCapcicnLabel		6
#define kLRCheck		7
#define kCapicl8Label		8
#define kLR2Check		9
#define kCapICNLabel		10
#define kLR3Check		11
#define kCapPICTLabel		12
#define kLR4Check		13
#define kCapicl9Label		14
#define kCheckboxCheck		15
#define kBevelBox		16
#define kCheckbox2Check		17
#define kNextCheck		18
#define kNext2Check		19


/*----------*/
Boolean		GetModalCheckboxes (
	DModalCheckboxesData*		ioData)
{
	Boolean			result = false;
	ModalCheckboxes*		dialog = NewModalCheckboxes ();

	result = AMDialog_RunModal ((AMDialog*)dialog, DLOG_ModalCheckboxes, (AMSignaler*)ioData);

	DeleteModalCheckboxes (dialog);

	return result;
}

//----------
ModalCheckboxes*		NewModalCheckboxes ()
{
	ModalCheckboxes*		dialog;

	dialog = (ModalCheckboxes*)malloc (sizeof (ModalCheckboxes));
	ModalCheckboxes_Init (dialog);
	SetClassID (dialog, classModalCheckboxes);

	return dialog;
}

//----------
void	DeleteModalCheckboxes (
	ModalCheckboxes*		dialog)
{
	ModalCheckboxes_Free (dialog);
	free (dialog);
}

//----------
void	ModalCheckboxes_Init (
	ModalCheckboxes*		self)
{
	AMDialog_Init ((AMDialog*)self);
}

//----------
void	ModalCheckboxes_Free (
	ModalCheckboxes*		self)
{
	AMDialog_Free ((AMDialog*)self);
}

//----------
void	ModalCheckboxes_FinishMake (
	ModalCheckboxes*		self)
{
	self->mOKHandle = AMDialog_GetControlItem ((AMDialog*)self, kOKButton);
	SetDefaultState (self->mOKHandle, true);
	SetDialogDefaultItem (((AMDialog*)self)->mDialog, kOKButton);
	self->mStandardHandle = AMDialog_GetControlItem ((AMDialog*)self, kStandardCheck);
	self->mXxHandle = AMDialog_GetControlItem ((AMDialog*)self, kXxCheck);
	self->mGraphicHandle = AMDialog_GetControlItem ((AMDialog*)self, kGraphicBox);
	self->mLRHandle = AMDialog_GetControlItem ((AMDialog*)self, kLRCheck);
	self->mLR2Handle = AMDialog_GetControlItem ((AMDialog*)self, kLR2Check);
	self->mLR3Handle = AMDialog_GetControlItem ((AMDialog*)self, kLR3Check);
	self->mLR4Handle = AMDialog_GetControlItem ((AMDialog*)self, kLR4Check);
	self->mCheckboxHandle = AMDialog_GetControlItem ((AMDialog*)self, kCheckboxCheck);
	self->mBevelHandle = AMDialog_GetControlItem ((AMDialog*)self, kBevelBox);
	self->mCheckbox2Handle = AMDialog_GetControlItem ((AMDialog*)self, kCheckbox2Check);
	SetBevelButtonGraphicAlignment (self->mCheckbox2Handle, kControlBevelButtonAlignCenter, 0, 0);
	self->mNextHandle = AMDialog_GetControlItem ((AMDialog*)self, kNextCheck);
	SetBevelButtonTextPlacement (self->mNextHandle, kControlBevelButtonPlaceToRightOfGraphic);
	SetBevelButtonTextAlignment (self->mNextHandle, kControlBevelButtonAlignTextFlushLeft, 0);
	SetBevelButtonGraphicAlignment (self->mNextHandle, kControlBevelButtonAlignLeft, 0, 0);
	self->mNext2Handle = AMDialog_GetControlItem ((AMDialog*)self, kNext2Check);
	SetBevelButtonTextPlacement (self->mNext2Handle, kControlBevelButtonPlaceBelowGraphic);
	SetBevelButtonTextAlignment (self->mNext2Handle, kControlBevelButtonAlignTextCenter, 0);
	SetBevelButtonGraphicAlignment (self->mNext2Handle, kControlBevelButtonAlignTop, 0, 0);
}

//----------
void	ModalCheckboxes_ConnectToData (
	ModalCheckboxes*		self,
	AMSignaler*		inData)
{
	AMDialog_ConnectToData ((AMDialog*)self, inData);
	self->mData = (DModalCheckboxesData*) inData;

	SetControlValue (self->mStandardHandle, GetStandard4 (self->mData));
	SetControlValue (self->mXxHandle, GetXx2 (self->mData));
	SetControlValue (self->mLRHandle, GetLR5 (self->mData));
	SetControlValue (self->mLR2Handle, GetLR6 (self->mData));
	SetControlValue (self->mLR3Handle, GetLR7 (self->mData));
	SetControlValue (self->mLR4Handle, GetLR8 (self->mData));
	SetControlValue (self->mCheckboxHandle, GetCheckbox3 (self->mData));
	SetControlValue (self->mCheckbox2Handle, GetCheckbox4 (self->mData));
	SetBevelButtonGraphicAlignment (self->mCheckbox2Handle, kControlBevelButtonAlignCenter, 0, 0);
	SetControlValue (self->mNextHandle, GetNext3 (self->mData));
	SetBevelButtonTextPlacement (self->mNextHandle, kControlBevelButtonPlaceToRightOfGraphic);
	SetBevelButtonTextAlignment (self->mNextHandle, kControlBevelButtonAlignTextFlushLeft, 0);
	SetBevelButtonGraphicAlignment (self->mNextHandle, kControlBevelButtonAlignLeft, 0, 0);
	SetControlValue (self->mNext2Handle, GetNext4 (self->mData));
	SetBevelButtonTextPlacement (self->mNext2Handle, kControlBevelButtonPlaceBelowGraphic);
	SetBevelButtonTextAlignment (self->mNext2Handle, kControlBevelButtonAlignTextCenter, 0);
	SetBevelButtonGraphicAlignment (self->mNext2Handle, kControlBevelButtonAlignTop, 0, 0);
}

//----------
void	ModalCheckboxes_DoItem (
	ModalCheckboxes*		self,
	SInt16		inItemHit)
{
	switch (inItemHit) {
	case kOKButton:
			AMDialog_SetResult ((AMDialog*)self, true);
		break;
	case kStandardCheck:
			SetStandard4 (self->mData, ToggleCheckbox (self->mStandardHandle));
		break;
	case kXxCheck:
			SetXx2 (self->mData, ToggleCheckbox (self->mXxHandle));
		break;
	case kLRCheck:
			SetLR5 (self->mData, ToggleCheckbox (self->mLRHandle));
		break;
	case kLR2Check:
			SetLR6 (self->mData, ToggleCheckbox (self->mLR2Handle));
		break;
	case kLR3Check:
			SetLR7 (self->mData, ToggleCheckbox (self->mLR3Handle));
		break;
	case kLR4Check:
			SetLR8 (self->mData, ToggleCheckbox (self->mLR4Handle));
		break;
	case kCheckboxCheck:
			SetCheckbox3 (self->mData, ToggleCheckbox (self->mCheckboxHandle));
		break;
	case kCheckbox2Check:
			SetCheckbox4 (self->mData, GetControlValue (self->mCheckbox2Handle));
		break;
	case kNextCheck:
			SetNext3 (self->mData, GetControlValue (self->mNextHandle));
		break;
	case kNext2Check:
			SetNext4 (self->mData, GetControlValue (self->mNext2Handle));
		break;

	} // switch
}

//----------
void	ModalCheckboxes_DataChanged (
	ModalCheckboxes*		self,
	long		inDataID)
{
	if (inDataID == idStandard4) {
		SetControlValue (self->mStandardHandle, GetStandard4 (self->mData));
	}
	if (inDataID == idXx2) {
		SetControlValue (self->mXxHandle, GetXx2 (self->mData));
	}
	if (inDataID == idLR5) {
		SetControlValue (self->mLRHandle, GetLR5 (self->mData));
	}
	if (inDataID == idLR6) {
		SetControlValue (self->mLR2Handle, GetLR6 (self->mData));
	}
	if (inDataID == idLR7) {
		SetControlValue (self->mLR3Handle, GetLR7 (self->mData));
	}
	if (inDataID == idLR8) {
		SetControlValue (self->mLR4Handle, GetLR8 (self->mData));
	}
	if (inDataID == idCheckbox3) {
		SetControlValue (self->mCheckboxHandle, GetCheckbox3 (self->mData));
	}
	if (inDataID == idCheckbox4) {
		SetControlValue (self->mCheckbox2Handle, GetCheckbox4 (self->mData));
	}
	if (inDataID == idNext3) {
		SetControlValue (self->mNextHandle, GetNext3 (self->mData));
	}
	if (inDataID == idNext4) {
		SetControlValue (self->mNext2Handle, GetNext4 (self->mData));
	}
}

//----------
Boolean		ModalCheckboxes_Filter (
	ModalCheckboxes*			self,
	EventRecord			*ioEvent,
	DialogItemIndex		*outItemHit)
{
	return AMDialog_Filter ((AMDialog*)self, ioEvent, outItemHit);
}
