/* ModalRadios.c -- Modal dialog */

#include <Types.h>
#include <Quickdraw.h>
#include <Controls.h>
#include <Dialogs.h>
#include <Events.h>
#include <Lists.h>
#include <Menus.h>
#include <TextEdit.h>
#include <Appearance.h>
#include <stdlib.h>

#include "ResourceDefs.h"
#include "Miscellany.h"
#include "ControlUtils.h"

#include "Dispatcher.h"
#include "ModalRadios.h"

#define kOKButton		1
#define kRadioGroupGroup		2
#define kStandardRadio		3
#define kGroupBox		4
#define kGroupGroup		5
#define kGroupRadio1		6
#define kGroupRadio2		7
#define kGroupRadio3		8
#define kGraphicBox		9
#define kGraphicGroup		10
#define kStopRadio		11
#define kGoRadio		12
#define kBevelBox		13
#define kBevelGroup		14
#define kRadioButtonRadio		15
#define kRadioButton2Radio		16
#define kTextBox		17
#define kTextGroup		18
#define kNameRadio		19
#define kKindRadio		20
#define kSizeRadio		21


/*----------*/
Boolean		GetModalRadios (
	DModalRadiosData*		ioData)
{
	Boolean			result = false;
	ModalRadios*		dialog = NewModalRadios ();

	result = AMDialog_RunModal ((AMDialog*)dialog, DLOG_ModalRadios, (AMSignaler*)ioData);

	DeleteModalRadios (dialog);

	return result;
}

//----------
ModalRadios*		NewModalRadios ()
{
	ModalRadios*		dialog;

	dialog = (ModalRadios*)malloc (sizeof (ModalRadios));
	ModalRadios_Init (dialog);
	SetClassID (dialog, classModalRadios);

	return dialog;
}

//----------
void	DeleteModalRadios (
	ModalRadios*		dialog)
{
	ModalRadios_Free (dialog);
	free (dialog);
}

//----------
void	ModalRadios_Init (
	ModalRadios*		self)
{
	AMDialog_Init ((AMDialog*)self);
}

//----------
void	ModalRadios_Free (
	ModalRadios*		self)
{
	AMDialog_Free ((AMDialog*)self);
}

//----------
void	ModalRadios_FinishMake (
	ModalRadios*		self)
{
	self->mOKHandle = AMDialog_GetControlItem ((AMDialog*)self, kOKButton);
	SetDefaultState (self->mOKHandle, true);
	SetDialogDefaultItem (((AMDialog*)self)->mDialog, kOKButton);
	self->mRadioGroupGroupHandle = AMDialog_GetControlItem ((AMDialog*)self, kRadioGroupGroup);
	self->mStandardHandle = AMDialog_GetControlItem ((AMDialog*)self, kStandardRadio);
	self->mGroupBoxHandle = AMDialog_GetControlItem ((AMDialog*)self, kGroupBox);
	self->mGroupGroupHandle = AMDialog_GetControlItem ((AMDialog*)self, kGroupGroup);
	self->mGroupRadio1Handle = AMDialog_GetControlItem ((AMDialog*)self, kGroupRadio1);
	self->mGroupRadio2Handle = AMDialog_GetControlItem ((AMDialog*)self, kGroupRadio2);
	self->mGroupRadio3Handle = AMDialog_GetControlItem ((AMDialog*)self, kGroupRadio3);
	self->mGraphicBoxHandle = AMDialog_GetControlItem ((AMDialog*)self, kGraphicBox);
	self->mGraphicGroupHandle = AMDialog_GetControlItem ((AMDialog*)self, kGraphicGroup);
	self->mStopHandle = AMDialog_GetControlItem ((AMDialog*)self, kStopRadio);
	self->mGoHandle = AMDialog_GetControlItem ((AMDialog*)self, kGoRadio);
	self->mBevelBoxHandle = AMDialog_GetControlItem ((AMDialog*)self, kBevelBox);
	self->mBevelGroupHandle = AMDialog_GetControlItem ((AMDialog*)self, kBevelGroup);
	self->mRadioButtonHandle = AMDialog_GetControlItem ((AMDialog*)self, kRadioButtonRadio);
	SetBevelButtonGraphicAlignment (self->mRadioButtonHandle, kControlBevelButtonAlignCenter, 0, 0);
	self->mRadioButton2Handle = AMDialog_GetControlItem ((AMDialog*)self, kRadioButton2Radio);
	SetBevelButtonGraphicAlignment (self->mRadioButton2Handle, kControlBevelButtonAlignCenter, 0, 0);
	self->mTextBoxHandle = AMDialog_GetControlItem ((AMDialog*)self, kTextBox);
	self->mTextGroupHandle = AMDialog_GetControlItem ((AMDialog*)self, kTextGroup);
	self->mNameHandle = AMDialog_GetControlItem ((AMDialog*)self, kNameRadio);
	self->mKindHandle = AMDialog_GetControlItem ((AMDialog*)self, kKindRadio);
	self->mSizeHandle = AMDialog_GetControlItem ((AMDialog*)self, kSizeRadio);
}

//----------
void	ModalRadios_ConnectToData (
	ModalRadios*		self,
	AMSignaler*		inData)
{
	AMDialog_ConnectToData ((AMDialog*)self, inData);
	self->mData = (DModalRadiosData*) inData;

	SetControlValue (self->mRadioGroupGroupHandle, GetRadioGroup2 (self->mData));
	SetControlValue (self->mGroupGroupHandle, GetGroup2 (self->mData));
	SetControlValue (self->mGraphicGroupHandle, GetGraphic3 (self->mData));
	SetControlValue (self->mBevelGroupHandle, GetBevel2 (self->mData));
	SetBevelButtonGraphicAlignment (self->mRadioButtonHandle, kControlBevelButtonAlignCenter, 0, 0);
	SetBevelButtonGraphicAlignment (self->mRadioButton2Handle, kControlBevelButtonAlignCenter, 0, 0);
	SetControlValue (self->mTextGroupHandle, GetText2 (self->mData));
}

//----------
void	ModalRadios_DoItem (
	ModalRadios*		self,
	SInt16		inItemHit)
{
	switch (inItemHit) {
	case kOKButton:
			AMDialog_SetResult ((AMDialog*)self, true);
		break;
	case kRadioGroupGroup:
			SetRadioGroup2 (self->mData, GetControlValue (self->mRadioGroupGroupHandle));
		break;
	case kGroupGroup:
			SetGroup2 (self->mData, GetControlValue (self->mGroupGroupHandle));
		break;
	case kGraphicGroup:
			SetGraphic3 (self->mData, GetControlValue (self->mGraphicGroupHandle));
		break;
	case kBevelGroup:
			SetBevel2 (self->mData, GetControlValue (self->mBevelGroupHandle));
		break;
	case kTextGroup:
			SetText2 (self->mData, GetControlValue (self->mTextGroupHandle));
		break;

	} // switch
}

//----------
void	ModalRadios_DataChanged (
	ModalRadios*		self,
	long		inDataID)
{
	if (inDataID == idRadioGroup2) {
		SetControlValue (self->mRadioGroupGroupHandle, GetRadioGroup2 (self->mData));
	}
	if (inDataID == idGroup2) {
		SetControlValue (self->mGroupGroupHandle, GetGroup2 (self->mData));
	}
	if (inDataID == idGraphic3) {
		SetControlValue (self->mGraphicGroupHandle, GetGraphic3 (self->mData));
	}
	if (inDataID == idBevel2) {
		SetControlValue (self->mBevelGroupHandle, GetBevel2 (self->mData));
	}
	if (inDataID == idText2) {
		SetControlValue (self->mTextGroupHandle, GetText2 (self->mData));
	}
}

//----------
Boolean		ModalRadios_Filter (
	ModalRadios*			self,
	EventRecord			*ioEvent,
	DialogItemIndex		*outItemHit)
{
	return AMDialog_Filter ((AMDialog*)self, ioEvent, outItemHit);
}
