/* ModalStuff.c -- Modal dialog */

#include <Types.h>
#include <Quickdraw.h>
#include <Controls.h>
#include <Dialogs.h>
#include <Events.h>
#include <Lists.h>
#include <Menus.h>
#include <TextEdit.h>
#include <Appearance.h>
#include <stdlib.h>

#include "ResourceDefs.h"
#include "Miscellany.h"
#include "ControlUtils.h"

#include "Dispatcher.h"
#include "ModalStuff.h"

#define kOKButton		1
#define kToolsPalette		2
#define kPopupsBox		3
#define kFromValuesList2Popup		4
#define kFromMenuPopup		5
#define kListsBox		6
#define kTextListList		7

static void		BuildTextListList	(ControlHandle		inControl);

/*----------*/
static void		BuildTextListList (
	ControlHandle		inControl)
{
	ListHandle		list;

	list = GetListHandle (inControl);
	AddToList ("\pOne",   list);
	AddToList ("\pTwo",   list);
	AddToList ("\pThree", list);
	AddToList ("\pInfinity",  list);

}

/*----------*/
Boolean		GetModalStuff (
	DModalStuffData*		ioData)
{
	Boolean			result = false;
	ModalStuff*		dialog = NewModalStuff ();

	result = AMDialog_RunModal ((AMDialog*)dialog, DLOG_ModalStuff, (AMSignaler*)ioData);

	DeleteModalStuff (dialog);

	return result;
}

//----------
ModalStuff*		NewModalStuff ()
{
	ModalStuff*		dialog;

	dialog = (ModalStuff*)malloc (sizeof (ModalStuff));
	ModalStuff_Init (dialog);
	SetClassID (dialog, classModalStuff);

	return dialog;
}

//----------
void	DeleteModalStuff (
	ModalStuff*		dialog)
{
	ModalStuff_Free (dialog);
	free (dialog);
}

//----------
void	ModalStuff_Init (
	ModalStuff*		self)
{
	AMDialog_Init ((AMDialog*)self);
}

//----------
void	ModalStuff_Free (
	ModalStuff*		self)
{
	AMDialog_Free ((AMDialog*)self);
}

//----------
void	ModalStuff_FinishMake (
	ModalStuff*		self)
{
	self->mOKHandle = AMDialog_GetControlItem ((AMDialog*)self, kOKButton);
	SetDefaultState (self->mOKHandle, true);
	SetDialogDefaultItem (((AMDialog*)self)->mDialog, kOKButton);
	self->mToolsHandle = AMDialog_GetControlItem ((AMDialog*)self, kToolsPalette);
	self->mPopupsHandle = AMDialog_GetControlItem ((AMDialog*)self, kPopupsBox);
	self->mFromValuesList2Handle = AMDialog_GetControlItem ((AMDialog*)self, kFromValuesList2Popup);
	self->mFromMenuHandle = AMDialog_GetControlItem ((AMDialog*)self, kFromMenuPopup);
	self->mListsHandle = AMDialog_GetControlItem ((AMDialog*)self, kListsBox);
	self->mTextListHandle = AMDialog_GetControlItem ((AMDialog*)self, kTextListList);
}

//----------
void	ModalStuff_ConnectToData (
	ModalStuff*		self,
	AMSignaler*		inData)
{
	AMDialog_ConnectToData ((AMDialog*)self, inData);
	self->mData = (DModalStuffData*) inData;

	SetControlValue (self->mToolsHandle, GetTools2 (self->mData));
	SetControlValue (self->mFromValuesList2Handle, GetFromValuesList3 (self->mData));
	SetControlValue (self->mFromMenuHandle, GetFromMenu2 (self->mData));
	BuildTextListList (self->mTextListHandle);
	SetListBoxChoice (self->mTextListHandle, GetTextList2 (self->mData));
}

//----------
void	ModalStuff_DoItem (
	ModalStuff*		self,
	SInt16		inItemHit)
{
	switch (inItemHit) {
	case kOKButton:
			AMDialog_SetResult ((AMDialog*)self, true);
		break;
	case kToolsPalette:
			SetTools2 (self->mData, GetControlValue (self->mToolsHandle));
		break;
	case kFromValuesList2Popup:
			SetFromValuesList3 (self->mData, GetControlValue (self->mFromValuesList2Handle));
		break;
	case kFromMenuPopup:
			SetFromMenu2 (self->mData, GetControlValue (self->mFromMenuHandle));
		break;
	case kTextListList:
			SetTextList2 (self->mData, GetListBoxChoice (self->mTextListHandle));
		break;

	} // switch
}

//----------
void	ModalStuff_DataChanged (
	ModalStuff*		self,
	long		inDataID)
{
	if (inDataID == idTools2) {
		SetControlValue (self->mToolsHandle, GetTools2 (self->mData));
	}
	if (inDataID == idFromValuesList3) {
		SetControlValue (self->mFromValuesList2Handle, GetFromValuesList3 (self->mData));
	}
	if (inDataID == idFromMenu2) {
		SetControlValue (self->mFromMenuHandle, GetFromMenu2 (self->mData));
	}
}

//----------
Boolean		ModalStuff_Filter (
	ModalStuff*			self,
	EventRecord			*ioEvent,
	DialogItemIndex		*outItemHit)
{
	return AMDialog_Filter ((AMDialog*)self, ioEvent, outItemHit);
}
