/* ModelessBars.c -- modeless dialog */

#include <Types.h>
#include <Quickdraw.h>
#include <Controls.h>
#include <Dialogs.h>
#include <Events.h>
#include <Lists.h>
#include <Menus.h>
#include <TextEdit.h>
#include <Appearance.h>
#include <stdlib.h>

#include "ResourceDefs.h"
#include "Miscellany.h"
#include "ControlUtils.h"

#include "Dispatcher.h"
#include "ModelessBars.h"

#define kBarsPanel		1
#define kScrollBarsLayer		2
#define kStandardScroll		3
#define kGraphicScroll		4
#define kSliderScroll		5
#define kTickMarksScroll		6
#define kNonDirectionalScroll		7
#define kLittleArrowsScroll		8
#define kSpinnerScroll		9
#define kVolumeControlScroll		10
#define kJimSSliderScroll		11
#define kProgressBarsLayer		12
#define kStandard2Bar			13
#define kIndeterminateBar			14
#define kChasingArrowsBar			15
#define kRectangleBar			16
#define kRoundRectBar			17
#define kBarberPoleBar			18
#define kRoundBarberBar			19


//----------
DialogPtr		ModelessBarsDialog = nil;

//----------
void	ModelessBars_Create ()
{
	ModelessBars*			dialog = NewModelessBars ();
	DModelessBarsData*		data = NewDModelessBarsData ();

	AMDialog_MakeDialog ((AMDialog*)dialog, DLOG_ModelessBars);
	ModelessBars_ConnectToData (dialog, (AMSignaler*)data);
}

//----------
void	ModelessBars_Show ()
{
	if (ModelessBarsDialog == nil) {
		ModelessBars_Create ();
	}
	if (ModelessBarsDialog != nil) {
		SelectWindow (ModelessBarsDialog);
		ShowWindow (ModelessBarsDialog);
	}
}

//----------
void	ModelessBars_Close ()
{
	HideWindow (ModelessBarsDialog);
}

//----------
ModelessBars*		NewModelessBars ()
{
	ModelessBars*		dialog;

	dialog = (ModelessBars*)malloc (sizeof (ModelessBars));
	ModelessBars_Init (dialog);
	SetClassID (dialog, classModelessBars);

	return dialog;
}

//----------
void	DeleteModelessBars (
	ModelessBars*		dialog)
{
	ModelessBars_Free (dialog);
	free (dialog);
}

//----------
void	ModelessBars_Init (
	ModelessBars*		self)
{
	AMDialog_Init ((AMDialog*)self);
}

//----------
void	ModelessBars_Free (
	ModelessBars*		self)
{
	AMDialog_Free ((AMDialog*)self);
}

//----------
void	ModelessBars_FinishMake (
	ModelessBars*		self)
{
	ModelessBarsDialog = ((AMDialog*)self)->mDialog;

	self->mBarsHandle = AMDialog_GetControlItem ((AMDialog*)self, kBarsPanel);
	self->mStandardHandle = AMDialog_GetControlItem ((AMDialog*)self, kStandardScroll);
	self->mGraphicHandle = AMDialog_GetControlItem ((AMDialog*)self, kGraphicScroll);
	self->mSliderHandle = AMDialog_GetControlItem ((AMDialog*)self, kSliderScroll);
	self->mTickMarksHandle = AMDialog_GetControlItem ((AMDialog*)self, kTickMarksScroll);
	self->mNonDirectionalHandle = AMDialog_GetControlItem ((AMDialog*)self, kNonDirectionalScroll);
	self->mLittleArrowsHandle = AMDialog_GetControlItem ((AMDialog*)self, kLittleArrowsScroll);
	self->mSpinnerHandle = AMDialog_GetControlItem ((AMDialog*)self, kSpinnerScroll);
	self->mVolumeControlHandle = AMDialog_GetControlItem ((AMDialog*)self, kVolumeControlScroll);
	self->mJimSSliderHandle = AMDialog_GetControlItem ((AMDialog*)self, kJimSSliderScroll);
	self->mStandard2Handle = AMDialog_GetControlItem ((AMDialog*)self, kStandard2Bar);
	self->mIndeterminateHandle = AMDialog_GetControlItem ((AMDialog*)self, kIndeterminateBar);
	self->mChasingArrowsHandle = AMDialog_GetControlItem ((AMDialog*)self, kChasingArrowsBar);
	self->mRectangleHandle = AMDialog_GetControlItem ((AMDialog*)self, kRectangleBar);
	self->mRoundRectHandle = AMDialog_GetControlItem ((AMDialog*)self, kRoundRectBar);
	self->mBarberPoleHandle = AMDialog_GetControlItem ((AMDialog*)self, kBarberPoleBar);
	self->mRoundBarberHandle = AMDialog_GetControlItem ((AMDialog*)self, kRoundBarberBar);
}

//----------
void	ModelessBars_ConnectToData (
	ModelessBars*		self,
	AMSignaler*		inData)
{
	AMDialog_ConnectToData ((AMDialog*)self, inData);
	self->mData = (DModelessBarsData*) inData;

	SetControlValue (self->mBarsHandle, GetBars3 (self->mData));
	SetLayerGroupValue (self->mBarsHandle, GetControlValue (self->mBarsHandle));
	SetControlValue (self->mStandardHandle, GetStandard8 (self->mData));
	SetControlValue (self->mGraphicHandle, GetGraphic6 (self->mData));
	SetControlValue (self->mSliderHandle, GetSlider3 (self->mData));
	SetControlValue (self->mTickMarksHandle, GetTickMarks3 (self->mData));
	SetControlValue (self->mNonDirectionalHandle, GetNonDirectional3 (self->mData));
	SetControlValue (self->mLittleArrowsHandle, GetLittleArrows3 (self->mData));
	SetControlValue (self->mSpinnerHandle, GetSpinner3 (self->mData));
	SetControlValue (self->mVolumeControlHandle, GetVolumeControl3 (self->mData));
	SetControlValue (self->mJimSSliderHandle, GetJimSSlider3 (self->mData));
	SetControlValue (self->mStandard2Handle, GetStandard9 (self->mData));
	SetControlValue (self->mIndeterminateHandle, GetIndeterminate3 (self->mData));
	SetControlValue (self->mChasingArrowsHandle, GetChasingArrows3 (self->mData));
	SetControlValue (self->mRectangleHandle, GetRectangle3 (self->mData));
	SetControlValue (self->mRoundRectHandle, GetRoundRect3 (self->mData));
	SetControlValue (self->mBarberPoleHandle, GetBarberPole3 (self->mData));
	SetControlValue (self->mRoundBarberHandle, GetRoundBarber3 (self->mData));
}

//----------
void	ModelessBars_DoItem (
	ModelessBars*		self,
	SInt16		inItemHit)
{
	switch (inItemHit) {
	case kBarsPanel:
			SetBars3 (self->mData, GetControlValue (self->mBarsHandle));
			SetLayerGroupValue (self->mBarsHandle, GetControlValue (self->mBarsHandle));
		break;
	case kStandardScroll:
			SetStandard8 (self->mData, GetControlValue (self->mStandardHandle));
		break;
	case kGraphicScroll:
			SetGraphic6 (self->mData, GetControlValue (self->mGraphicHandle));
		break;
	case kSliderScroll:
			SetSlider3 (self->mData, GetControlValue (self->mSliderHandle));
		break;
	case kTickMarksScroll:
			SetTickMarks3 (self->mData, GetControlValue (self->mTickMarksHandle));
		break;
	case kNonDirectionalScroll:
			SetNonDirectional3 (self->mData, GetControlValue (self->mNonDirectionalHandle));
		break;
	case kLittleArrowsScroll:
			SetLittleArrows3 (self->mData, GetControlValue (self->mLittleArrowsHandle));
		break;
	case kSpinnerScroll:
			SetSpinner3 (self->mData, GetControlValue (self->mSpinnerHandle));
		break;
	case kVolumeControlScroll:
			SetVolumeControl3 (self->mData, GetControlValue (self->mVolumeControlHandle));
		break;
	case kJimSSliderScroll:
			SetJimSSlider3 (self->mData, GetControlValue (self->mJimSSliderHandle));
		break;

	} // switch
}

//----------
void	ModelessBars_DataChanged (
	ModelessBars*		self,
	long		inDataID)
{
	if (inDataID == idBars3) {
		SetControlValue (self->mBarsHandle, GetBars3 (self->mData));
		SetLayerGroupValue (self->mBarsHandle, GetBars3 (self->mData));
	}
	if (inDataID == idStandard8) {
		SetControlValue (self->mStandardHandle, GetStandard8 (self->mData));
	}
	if (inDataID == idGraphic6) {
		SetControlValue (self->mGraphicHandle, GetGraphic6 (self->mData));
	}
	if (inDataID == idSlider3) {
		SetControlValue (self->mSliderHandle, GetSlider3 (self->mData));
	}
	if (inDataID == idTickMarks3) {
		SetControlValue (self->mTickMarksHandle, GetTickMarks3 (self->mData));
	}
	if (inDataID == idNonDirectional3) {
		SetControlValue (self->mNonDirectionalHandle, GetNonDirectional3 (self->mData));
	}
	if (inDataID == idLittleArrows3) {
		SetControlValue (self->mLittleArrowsHandle, GetLittleArrows3 (self->mData));
	}
	if (inDataID == idSpinner3) {
		SetControlValue (self->mSpinnerHandle, GetSpinner3 (self->mData));
	}
	if (inDataID == idVolumeControl3) {
		SetControlValue (self->mVolumeControlHandle, GetVolumeControl3 (self->mData));
	}
	if (inDataID == idJimSSlider3) {
		SetControlValue (self->mJimSSliderHandle, GetJimSSlider3 (self->mData));
	}
	if (inDataID == idStandard9) {
		SetControlValue (self->mStandard2Handle, GetStandard9 (self->mData));
	}
	if (inDataID == idIndeterminate3) {
		SetControlValue (self->mIndeterminateHandle, GetIndeterminate3 (self->mData));
	}
	if (inDataID == idChasingArrows3) {
		SetControlValue (self->mChasingArrowsHandle, GetChasingArrows3 (self->mData));
	}
	if (inDataID == idRectangle3) {
		SetControlValue (self->mRectangleHandle, GetRectangle3 (self->mData));
	}
	if (inDataID == idRoundRect3) {
		SetControlValue (self->mRoundRectHandle, GetRoundRect3 (self->mData));
	}
	if (inDataID == idBarberPole3) {
		SetControlValue (self->mBarberPoleHandle, GetBarberPole3 (self->mData));
	}
	if (inDataID == idRoundBarber3) {
		SetControlValue (self->mRoundBarberHandle, GetRoundBarber3 (self->mData));
	}
}

//----------
Boolean		ModelessBars_Filter (
	ModelessBars*			self,
	EventRecord			*ioEvent,
	DialogItemIndex		*outItemHit)
{
	return AMDialog_Filter ((AMDialog*)self, ioEvent, outItemHit);
}
