/* MainWindow.c */

#include <Types.h>
#include <Quickdraw.h>
#include <Controls.h>
#include <Dialogs.h>
#include <Events.h>
#include <Lists.h>
#include <Menus.h>
#include <Resources.h>
#include <Sound.h>
#include <TextEdit.h>
#include <ToolUtils.h>
#include <Appearance.h>
#include <stdlib.h>

#include "Globals.h"
#include "ResourceDefs.h"
#include "DoScrap.h"
#include "Miscellany.h"
#include "Scrolling.h"
#include "ControlUtils.h"
#include "Dispatcher.h"
#include "DDocData.h"
#include "TemperatureEngine.h"
#include "TemperatureDoc.h"
#include "MainWindow.h"


static	TemperatureEngine* 	 GetEngine	(MainWindow*	self);

static	void	DoUndo		(MainWindow*	self);
static	void	DoCut		(MainWindow*	self);
static	void	DoCopy		(MainWindow*	self);
static	void	DoPaste		(MainWindow*	self);
static	void	DoClear		(MainWindow*	self);
static	void	DoSelectAll		(MainWindow*	self);
static	void	DoShowClipboard	(MainWindow*	self);


//----------
MainWindow*		NewMainWindow ()
{
	MainWindow*		window;

	window = (MainWindow*)malloc (sizeof (MainWindow));
	MainWindow_Init (window);
	SetClassID (window, classMainWindow);

	return window;
}

//----------
void	DeleteMainWindow (
	MainWindow*		window)
{
	MainWindow_Free (window);
	free (window);
}

//----------
void	MainWindow_Create (
	AMDoc*			inDoc,
	DDocData*		inData)
{
	MainWindow*		winObj = NewMainWindow ();

	if (winObj != nil) {
		MainWindow_Open (winObj, inDoc, inData);
	}
}

//----------
void	MainWindow_Init (
	MainWindow*		self)
{
}

//----------
void	MainWindow_Free (
	MainWindow*		self)
{
}

//----------
TemperatureEngine*	GetEngine (
	MainWindow*		self)
{
	return (TemperatureEngine*) self->super.mDoc->mEngine;
}

/*----------*/
void	MainWindow_Open (
	MainWindow*		self,
	AMDoc*			inDoc,
	DDocData*		inData)
{
	WindowPtr		window;
	Handle			wftb;

	self->super.mDoc = inDoc;
	self->mData = inData;
	AddResponder ((AMSignaler*) self->mData, (AMResponder*) self);

	window = GetNewCWindow (WIND_MainWindow, nil, (WindowPtr) -1L);
	if (AMEngine_GetFilename (self->super.mDoc->mEngine) [0] != 0) {
		SetWTitle (window, AMEngine_GetFilename (self->super.mDoc->mEngine));
	}
	self->super.mWindow = window;
	((TemperatureDoc*)self->super.mDoc)->mMainWindowPtr = window;

	SetWindowKind (window, 'AM');
	SetWRefCon (window, (long) self);
	SetPort (window);
	SetInfo (window);

	wftb = GetResource ('Wftb', WIND_MainWindow);

	CreateRootControl (window, &self->super.mRootControl);

	self->super.vScroll = nil;
	self->super.hScroll = nil;


	self->mCentigradeLabel = GetNewControl (CNTL_Centigrade, window);
	SetWindowItemFont (self->mCentigradeLabel, wftb, 1);
	SetControlFromTEXT (self->mCentigradeLabel, TEXT_Centigrade);

	self->mEditCentigradeHandle = GetNewControl (CNTL_EditCentigrade, window);
	SetWindowItemFont (self->mEditCentigradeHandle, wftb, 2);
	SetControlTextValue (self->mEditCentigradeHandle, GetCentigrade (self->mData));

	self->mFahrenheitLabel = GetNewControl (CNTL_Fahrenheit, window);
	SetWindowItemFont (self->mFahrenheitLabel, wftb, 3);
	SetControlFromTEXT (self->mFahrenheitLabel, TEXT_Fahrenheit);

	self->mEditFahrenheitHandle = GetNewControl (CNTL_EditFahrenheit, window);
	SetWindowItemFont (self->mEditFahrenheitHandle, wftb, 4);
	SetControlTextValue (self->mEditFahrenheitHandle, GetFahrenheit (self->mData));

	self->mCentSliderHandle = GetNewControl (CNTL_CentSlider, window);
	SetWindowItemFont (self->mCentSliderHandle, wftb, 5);
	SetControlValue (self->mCentSliderHandle, GetCentigrade (self->mData));

	self->mFahrBarHandle = GetNewControl (CNTL_FahrBar, window);
	SetWindowItemFont (self->mFahrBarHandle, wftb, 6);
	SetControlValue (self->mFahrBarHandle, GetFahrenheit (self->mData));

	AdvanceKeyboardFocus (window);

	ShowWindow (window);
}

/*----------*/
void	MainWindow_Close (
	MainWindow*		self)
{
	RemoveResponder ((AMSignaler*) self->mData, (AMResponder*) self);

	((TemperatureDoc*)self->super.mDoc)->mMainWindowPtr = nil;
	SetInfo (nil);
	HideWindow (self->super.mWindow);
	DisposeWindow (self->super.mWindow);

	DeleteMainWindow (self);
}

/*----------*/
void	MainWindow_Track (
	MainWindow*		self,
	ControlHandle	whichControl,
	short			whichPart,
	Point			where)
{
	Rect			bounds;
	short			newValue;

	if (whichControl == self->mEditCentigradeHandle) {
		AMWindow_HandleEditClick ((AMWindow*) self, self->mEditCentigradeHandle, where);
	}
	if (whichControl == self->mEditFahrenheitHandle) {
		AMWindow_HandleEditClick ((AMWindow*) self, self->mEditFahrenheitHandle, where);
	}
	if (whichControl == self->mCentSliderHandle) {
		HandleControlClick (self->mCentSliderHandle, where, curEvent.modifiers, nil);
		SetCentigrade (self->mData, GetControlValue (self->mCentSliderHandle));
	}
}

//----------
void	MainWindow_DataChanged (
	MainWindow*		self,
	long			inDataID)
{
	if (inDataID == idCentigrade) {
		SetControlTextValue (self->mEditCentigradeHandle, GetCentigrade (self->mData));
	}
	if (inDataID == idFahrenheit) {
		SetControlTextValue (self->mEditFahrenheitHandle, GetFahrenheit (self->mData));
	}
	if (inDataID == idCentigrade) {
		SetControlValue (self->mCentSliderHandle, GetCentigrade (self->mData));
	}
	if (inDataID == idFahrenheit) {
		SetControlValue (self->mFahrBarHandle, GetFahrenheit (self->mData));
	}
}

/*----------*/
void	MainWindow_MouseIn (
	MainWindow*		self,
	Point			where,
	short			modifiers)
{
	Rect		bounds;

}

//----------
void	MainWindow_ExitCurField (
	MainWindow*		self)
{
	ControlHandle	focus;

	GetKeyboardFocus (self->super.mWindow, &focus);

	if (focus == nil) {
		// nothing to exit

	} else if (focus == self->mEditCentigradeHandle) {
		SetCentigrade (self->mData, GetControlTextValue (self->mEditCentigradeHandle));
	} else if (focus == self->mEditFahrenheitHandle) {
		SetFahrenheit (self->mData, GetControlTextValue (self->mEditFahrenheitHandle));
	}
}

/*----------*/
void	MainWindow_TypeIn (
	MainWindow*		self,
	char			ch)
{
	ControlHandle	focus;
	short			keyCode;

	GetKeyboardFocus (self->super.mWindow, &focus);

	if ((ch == charEnter)
	||  (ch == charReturn)) {
		MainWindow_ExitCurField (self);	// Dispatch
	} else if (ch == charEsc) {
	} else if (ch == charTab) {
		AMWindow_DoTab ((AMWindow*) self, (curEvent.modifiers & optionKey) != 0);
	} else if (focus != nil) {
		keyCode = curEvent.message & keyCodeMask;
		HandleControlKey (focus, keyCode, ch, curEvent.modifiers);
		AMEngine_SetDirty (self->super.mDoc->mEngine);
	} else {
		SysBeep (1);
	}
}

/*----------*/
void	MainWindow_Resize (
	MainWindow*		self)
{
	/* application-specific code to resize items in window */
}

/*----------*/
void	MainWindow_Scroll (
	MainWindow*		self,
	short			newValue,
	short			oldValue)
{
	/* application-specific code to scroll window */
	if (gWhichScroll == self->super.vScroll) {
	} else {	// horizontal
	}
}

//----------
void	DoUndo (
	MainWindow*		self)
{
} // DoUndo

//----------
void	DoCut (
	MainWindow*		self)
{
	TEHandle		curTE = AMWindow_GetCurTE ((AMWindow*) self);

	if (curTE != nil) {
		TECut (curTE);
		AMEngine_SetDirty (self->super.mDoc->mEngine);
		scrapDirty = true;
	}
} // DoCut

//----------
void	DoCopy (
	MainWindow*		self)
{
	TEHandle		curTE = AMWindow_GetCurTE ((AMWindow*) self);

	if (curTE != nil) {
		TECopy (curTE);
		scrapDirty = true;
	}
} // DoCopy

//----------
void	DoPaste (
	MainWindow*		self)
{
	TEHandle		curTE = AMWindow_GetCurTE ((AMWindow*) self);

	if (curTE != nil) {
		TEPaste (curTE);
		AMEngine_SetDirty (self->super.mDoc->mEngine);
	}
} // DoPaste

//----------
void	DoClear (
	MainWindow*		self)
{
	TEHandle		curTE = AMWindow_GetCurTE ((AMWindow*) self);

	if (curTE != nil) {
		TEDelete (curTE);
		AMEngine_SetDirty (self->super.mDoc->mEngine);
	}
} // DoClear

//----------
void	DoSelectAll (
	MainWindow*		self)
{
	TEHandle		curTE = AMWindow_GetCurTE ((AMWindow*) self);

	if (curTE != nil) {
		TESetSelect (0, 32767, curTE);
	}
} // DoSelectAll

//----------
void	DoShowClipboard (
	MainWindow*		self)
{
} // DoShowClipboard

//----------
Boolean		MainWindow_DoCommand (
	MainWindow*		self,
	long			inCommand)
{
	Boolean		result = true;

	switch (inCommand) {
		case cmdUndo:
				DoUndo (self);
			break;
		case cmdCut:
				DoCut (self);
			break;
		case cmdCopy:
				DoCopy (self);
			break;
		case cmdPaste:
				DoPaste (self);
			break;
		case cmdClear:
				DoClear (self);
			break;
		case cmdSelectAll:
				DoSelectAll (self);
			break;
		case cmdShowClipboard:
				DoShowClipboard (self);
			break;

		default:
				result = false;
	} // switch

	return result;
}
